@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-05-09'; # DATE
-our $VERSION = '1.54'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '1.55'; # VERSION
 
 use 5.010001;
 use strict;
@@ -952,15 +952,6 @@ sub _parse_argv2 {
 
         return $ga_res unless $ga_res->[0] == 200;
 
-        require Perinci::Sub::CoerceArgs;
-        my $coerce_res = Perinci::Sub::CoerceArgs::coerce_args(
-            meta                => $meta,
-            meta_is_normalized  => 1,
-            args                => $ga_res->[2],
-        );
-
-        return $coerce_res unless $coerce_res->[0] == 200;
-
         # restore
         for (keys %$copts) {
             $copts->{$_}{handler} = $old_handlers{$_};
@@ -1451,7 +1442,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.54 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-09.
+This document describes version 1.55 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-20.
 
 =head1 DESCRIPTION
 
