@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-05-09'; # DATE
-our $VERSION = '1.54'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '1.55'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -215,15 +215,16 @@ sub hook_before_action {
             next unless $schema;
             unless ($validators{"$schema"}) {
                 my $v = Data::Sah::gen_validator($schema, {
-                    return_type => 'str',
+                    return_type => 'str+val',
                     schema_is_normalized => 1,
                 });
                 $validators{"$schema"} = $v;
             }
             my $res = $validators{"$schema"}->($r->{args}{$arg});
-            if ($res) {
-                die [400, "Argument '$arg' fails validation: $res"];
+            if ($res->[0]) {
+                die [400, "Argument '$arg' fails validation: $res->[0]"];
             }
+            $r->{args}{$arg} = $res->[1];
         }
 
         if ($meta->{args_rels}) {
@@ -470,7 +471,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.54 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-09.
+This document describes version 1.55 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-05-20.
 
 =head1 SYNOPSIS
 
